@@ -15,10 +15,10 @@
 # specific language governing permissions and limitations
 # under the License.
 
-package Search::Elasticsearch::Client::7_0::Direct::Features;
-$Search::Elasticsearch::Client::7_0::Direct::Features::VERSION = '7.717';
+package Search::Elasticsearch::Client::8_0::Direct::Features;
+$Search::Elasticsearch::Client::8_0::Direct::Features::VERSION = '8.00';
 use Moo;
-with 'Search::Elasticsearch::Client::7_0::Role::API';
+with 'Search::Elasticsearch::Client::8_0::Role::API';
 with 'Search::Elasticsearch::Role::Client::Direct';
 use namespace::clean;
 
@@ -32,22 +32,36 @@ __PACKAGE__->_install_api('features');
 
 =head1 NAME
 
-Search::Elasticsearch::Client::7_0::Direct::Features - Features API of Search::Elasticsearch 7.x
+Search::Elasticsearch::Client::8_0::Direct::Features - Features API for Search::Elasticsearch 8.x
 
 =head1 VERSION
 
-version 7.717
+version 8.00
+
+=head1 SYNOPSIS
+
+    my $response = $es->features->get_features(...);
 
 =head2 DESCRIPTION
 
-The full documentation for Features API is available here:
-L<https://www.elastic.co/guide/en/elasticsearch//reference/master/features-apis.html>
+This class extends the L<Search::Elasticsearch> client with a C<features>
+namespace, to support the API for the
+L<Features|https://www.elastic.co/guide/en/elasticsearch/reference/current/features-apis.html> plugin for Elasticsearch.
 
-=head1 FOLLOW METHODS
+=head1 METHODS
 
-=head2 C<follow()>
+The full documentation for the Features plugin is available here:
+L<https://www.elastic.co/guide/en/elasticsearch/reference/current/features-apis.html>
 
-    my $response = $es->features->get_features();
+=head2 C<explore()>
+
+    $response = $es->features->get_features();
+
+The C<get_features()> method Gets a list of features which can be included in snapshots
+using the feature_states field when creating a snapshot.
+
+See the L<get_features|https://www.elastic.co/guide/en/elasticsearch/reference/current/get-features-api.html>
+for more information.
 
 =head1 AUTHOR
 
@@ -65,5 +79,6 @@ This is free software, licensed under:
 
 __END__
 
-# ABSTRACT: Features API of Search::Elasticsearch 7.x
+# ABSTRACT: Features API for Search::Elasticsearch 8.x
+
 
